Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7)

Unified Diff: source/i18n/unicode/udatpg.h

Issue 1621843002: ICU 56 update step 1 (Closed) Base URL: https://chromium.googlesource.com/chromium/deps/icu.git@561
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « source/i18n/unicode/udateintervalformat.h ('k') | source/i18n/unicode/udisplaycontext.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: source/i18n/unicode/udatpg.h
diff --git a/source/i18n/unicode/udatpg.h b/source/i18n/unicode/udatpg.h
index 7e8ca47274427aff2d399a7efce0f757882933d8..aa4ca7a923cf19c9319c3b3cc1f8fae666468a30 100644
--- a/source/i18n/unicode/udatpg.h
+++ b/source/i18n/unicode/udatpg.h
@@ -1,7 +1,7 @@
/*
*******************************************************************************
*
-* Copyright (C) 2007-2012, International Business Machines
+* Copyright (C) 2007-2015, International Business Machines
* Corporation and others. All Rights Reserved.
*
*******************************************************************************
@@ -259,7 +259,8 @@ udatpg_getBestPatternWithOptions(UDateTimePatternGenerator *dtpg,
* Consecutive calls to this function do not affect each other,
* but this function cannot be used concurrently on a single generator object.
*
* @param dtpg a pointer to UDateTimePatternGenerator.
* @param pattern input pattern, such as "dd/MMM".
* @param length the length of pattern.
* @param skeleton such as "MMMdd"
@@ -270,7 +271,7 @@ udatpg_getBestPatternWithOptions(UDateTimePatternGenerator *dtpg,
* @stable ICU 3.8
*/
U_STABLE int32_t U_EXPORT2
-udatpg_getSkeleton(UDateTimePatternGenerator *dtpg,
+udatpg_getSkeleton(UDateTimePatternGenerator *unusedDtpg,
const UChar *pattern, int32_t length,
UChar *skeleton, int32_t capacity,
UErrorCode *pErrorCode);
@@ -288,7 +289,8 @@ udatpg_getSkeleton(UDateTimePatternGenerator *dtpg,
* Consecutive calls to this function do not affect each other,
* but this function cannot be used concurrently on a single generator object.
*
* @param dtpg a pointer to UDateTimePatternGenerator.
* @param pattern input pattern, such as "dd/MMM".
* @param length the length of pattern.
* @param baseSkeleton such as "Md"
@@ -299,7 +301,7 @@ udatpg_getSkeleton(UDateTimePatternGenerator *dtpg,
* @stable ICU 3.8
*/
U_STABLE int32_t U_EXPORT2
-udatpg_getBaseSkeleton(UDateTimePatternGenerator *dtpg,
+udatpg_getBaseSkeleton(UDateTimePatternGenerator *unusedDtpg,
const UChar *pattern, int32_t length,
UChar *baseSkeleton, int32_t capacity,
UErrorCode *pErrorCode);
@@ -409,14 +411,16 @@ udatpg_getAppendItemName(const UDateTimePatternGenerator *dtpg,
int32_t *pLength);
/**
- * The date time format is a message format pattern used to compose date and
- * time patterns. The default value is "{0} {1}", where {0} will be replaced
- * by the date pattern and {1} will be replaced by the time pattern.
+ * The DateTimeFormat is a message format pattern used to compose date and
+ * time patterns. The default pattern in the root locale is "{1} {0}", where
+ * {1} will be replaced by the date pattern and {0} will be replaced by the
+ * time pattern; however, other locales may specify patterns such as
+ * "{1}, {0}" or "{1} 'at' {0}", etc.
* <p>
* This is used when the input skeleton contains both date and time fields,
* but there is not a close match among the added patterns. For example,
* suppose that this object was created by adding "dd-MMM" and "hh:mm", and
- * its datetimeFormat is the default "{0} {1}". Then if the input skeleton
+ * its DateTimeFormat is the default "{1} {0}". Then if the input skeleton
* is "MMMdhmm", there is not an exact match, so the input skeleton is
* broken up into two components "MMMd" and "hmm". There are close matches
* for those two skeletons, so the result is put together with this pattern,
@@ -424,8 +428,8 @@ udatpg_getAppendItemName(const UDateTimePatternGenerator *dtpg,
*
* @param dtpg a pointer to UDateTimePatternGenerator.
* @param dtFormat
- * message format pattern, here {0} will be replaced by the date
- * pattern and {1} will be replaced by the time pattern.
+ * message format pattern, here {1} will be replaced by the date
+ * pattern and {0} will be replaced by the time pattern.
* @param length the length of dtFormat.
* @stable ICU 3.8
*/
@@ -259,7 +259,8 @@ udatpg_getBestPatternWithOptions(UDateTimePatternGenerator *dtpg,
* but this function cannot be used concurrently on a single generator object.
*
- * @param dtpg a pointer to UDateTimePatternGenerator.
+ * @param unusedDtpg a pointer to UDateTimePatternGenerator.
+ * This parameter is no longer used. Callers may pass NULL.
* @param pattern input pattern, such as "dd/MMM".
* @param length the length of pattern.
@@ -288,7 +289,8 @@ udatpg_getSkeleton(UDateTimePatternGenerator *dtpg,
* but this function cannot be used concurrently on a single generator object.
*
- * @param dtpg a pointer to UDateTimePatternGenerator.
+ * @param unusedDtpg a pointer to UDateTimePatternGenerator.
+ * This parameter is no longer used. Callers may pass NULL.
* @param pattern input pattern, such as "dd/MMM".
* @param length the length of pattern.
« no previous file with comments | « source/i18n/unicode/udateintervalformat.h ('k') | source/i18n/unicode/udisplaycontext.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698